@@ -100,6 +100,15 @@ def is_modifiable_project(user, obj):
     return False if obj.is_remote() else True
 
 
+@rules.predicate
+def can_modify_project_data(user, obj):
+    """
+    Whether or not project app data can be modified, due to e.g. project
+    archiving status.
+    """
+    return not obj.archive
+
+
 @rules.predicate
 def can_create_projects(user, obj):
     """Whether or not new projects can be generated on the site"""
