@@ -56,7 +56,7 @@ class ProjectMixin:
     """Helper mixin for Project creation"""
 
     @classmethod
-    def _make_project(
+    def make_project(
         cls,
         title,
         type,
@@ -64,6 +64,7 @@ class ProjectMixin:
         description='',
         readme=None,
         public_guest_access=False,
+        archive=False,
         sodar_uuid=None,
     ):
         """Make and save a Project"""
@@ -73,6 +74,7 @@ class ProjectMixin:
             'parent': parent,
             'description': description,
             'readme': readme,
+            'archive': archive,
             'public_guest_access': public_guest_access,
         }
         if sodar_uuid:
@@ -86,7 +88,7 @@ class ProjectInviteMixin:
     """Helper mixin for ProjectInvite creation"""
 
     @classmethod
-    def _make_invite(
+    def make_invite(
         cls,
         email,
         project,
@@ -118,7 +120,7 @@ class AppSettingMixin:
     """Helper mixin for AppSetting creation"""
 
     @classmethod
-    def _make_setting(
+    def make_setting(
         cls,
         app_name,
         name,
@@ -154,7 +156,7 @@ class ProjectUserTagMixin:
     """Helper mixin for ProjectUserTag creation"""
 
     @classmethod
-    def _make_tag(cls, project, user, name):
+    def make_tag(cls, project, user, name):
         """Make and save a ProjectUserTag"""
         values = {'project': project, 'user': user, 'name': name}
         tag = ProjectUserTag(**values)
@@ -166,7 +168,7 @@ class RemoteSiteMixin:
     """Helper mixin for RemoteSite creation"""
 
     @classmethod
-    def _make_site(
+    def make_site(
         cls,
         name,
         url,
@@ -193,13 +195,12 @@ class RemoteProjectMixin:
     """Helper mixin for RemoteProject creation"""
 
     @classmethod
-    def _make_remote_project(
+    def make_remote_project(
         cls, project_uuid, site, level, date_access=None, project=None
     ):
         """Make and save a RemoteProject"""
         if isinstance(project_uuid, str):
             project_uuid = uuid.UUID(project_uuid)
-
         values = {
             'project_uuid': project_uuid,
             'site': site,
@@ -218,35 +219,32 @@ class RemoteTargetMixin(RemoteSiteMixin, RemoteProjectMixin):
     """Helper mixin for setting up the site as TARGET for testing"""
 
     @classmethod
-    def _set_up_as_target(cls, projects):
+    def set_up_as_target(cls, projects):
         """Set up current site as a target site"""
-        source_site = cls._make_site(
+        source_site = cls.make_site(
             name='Test Source',
             url='http://0.0.0.0',
             mode=SITE_MODE_SOURCE,
             description='',
             secret=build_secret(),
         )
-
         remote_projects = []
-
         for project in projects:
             remote_projects.append(
-                cls._make_remote_project(
+                cls.make_remote_project(
                     project_uuid=project.sodar_uuid,
                     project=project,
                     site=source_site,
                     level=SODAR_CONSTANTS['REMOTE_LEVEL_READ_ROLES'],
                 )
             )
-
         return source_site, remote_projects
 
 
-class SodarUserMixin:
+class SODARUserMixin:
     """Helper mixin for LDAP SodarUser creation"""
 
-    def _make_sodar_user(
+    def make_sodar_user(
         self,
         username,
         name,
@@ -260,13 +258,10 @@ class SodarUserMixin:
         user.name = name
         user.first_name = first_name
         user.last_name = last_name
-
         if email:
             user.email = email
-
         if sodar_uuid:
             user.sodar_uuid = sodar_uuid
-
         user.save()
         return user
 
@@ -276,17 +271,17 @@ class TestProject(ProjectMixin, TestCase):
 
     def setUp(self):
         # Top level category
-        self.category_top = self._make_project(
+        self.category_top = self.make_project(
             title='TestCategoryTop', type=PROJECT_TYPE_CATEGORY, parent=None
         )
         # Subproject under category_top
-        self.project_sub = self._make_project(
+        self.project_sub = self.make_project(
             title='TestProjectSub',
             type=PROJECT_TYPE_PROJECT,
             parent=self.category_top,
         )
         # Top level project
-        self.project_top = self._make_project(
+        self.project_top = self.make_project(
             title='TestProjectTop', type=PROJECT_TYPE_PROJECT, parent=None
         )
 
@@ -301,6 +296,7 @@ class TestProject(ProjectMixin, TestCase):
             'sodar_uuid': self.project_sub.sodar_uuid,
             'description': '',
             'public_guest_access': False,
+            'archive': False,
             'has_public_children': False,
         }
         model_dict = model_to_dict(self.project_sub)
@@ -330,7 +326,7 @@ class TestProject(ProjectMixin, TestCase):
         """Test title validation: title can't be equal between subproject and
         parent"""
         with self.assertRaises(ValidationError):
-            self._make_project(
+            self.make_project(
                 title='TestCategoryTop',
                 type=PROJECT_TYPE_PROJECT,
                 parent=self.category_top,
@@ -339,7 +335,7 @@ class TestProject(ProjectMixin, TestCase):
     def test_validate_parent_type(self):
         """Test parent type validation"""
         with self.assertRaises(ValidationError):
-            self._make_project(
+            self.make_project(
                 title='FailProject',
                 type=PROJECT_TYPE_PROJECT,
                 parent=self.project_top,
@@ -392,13 +388,29 @@ class TestProject(ProjectMixin, TestCase):
     def test_set_public(self):
         """Test Project.set_public()"""
         self.assertFalse(self.project_sub.public_guest_access)
-        self.project_sub.set_public()  # Default = true
+        self.project_sub.set_public()  # Default = True
         self.assertTrue(self.project_sub.public_guest_access)
         self.project_sub.set_public(False)
         self.assertFalse(self.project_sub.public_guest_access)
         self.project_sub.set_public(True)
         self.assertTrue(self.project_sub.public_guest_access)
 
+    def test_set_archive(self):
+        """Test Project.set_archive()"""
+        self.assertFalse(self.project_sub.archive)
+        self.project_sub.set_archive()  # Default = True
+        self.assertTrue(self.project_sub.archive)
+        self.project_sub.set_archive(False)
+        self.assertFalse(self.project_sub.archive)
+        self.project_sub.set_archive(True)
+        self.assertTrue(self.project_sub.archive)
+
+    def test_set_archive_category(self):
+        """Test Project.set_archive() for a category (should fail)"""
+        self.assertFalse(self.category_top.archive)
+        with self.assertRaises(ValidationError):
+            self.category_top.set_archive()
+
 
 class TestRole(TestCase):
     def setUp(self):
@@ -409,6 +421,7 @@ class TestRole(TestCase):
         expected = {
             'id': self.role.pk,
             'name': PROJECT_ROLE_OWNER,
+            'rank': 10,
             'description': self.role.description,
         }
         self.assertEqual(model_to_dict(self.role), expected)
@@ -428,7 +441,7 @@ class RoleAssignmentMixin:
     """Helper mixin for RoleAssignment creation"""
 
     @classmethod
-    def _make_assignment(cls, project, user, role):
+    def make_assignment(cls, project, user, role):
         """Make and save a RoleAssignment"""
         values = {'project': project, 'user': user, 'role': role}
         result = RoleAssignment(**values)
@@ -442,17 +455,17 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
     def setUp(self):
         # Init projects/categories
         # Top level category
-        self.category_top = self._make_project(
+        self.category_top = self.make_project(
             title='TestCategoryTop', type=PROJECT_TYPE_CATEGORY, parent=None
         )
         # Subproject under category_top
-        self.project_sub = self._make_project(
+        self.project_sub = self.make_project(
             title='TestProjectSub',
             type=PROJECT_TYPE_PROJECT,
             parent=self.category_top,
         )
         # Top level project
-        self.project_top = self._make_project(
+        self.project_top = self.make_project(
             title='TestProjectTop', type=PROJECT_TYPE_PROJECT, parent=None
         )
 
@@ -475,7 +488,7 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
         self.user_frank = self.make_user('frank')
 
         # Init assignment
-        self.assignment_owner = self._make_assignment(
+        self.assignment_owner = self.make_assignment(
             self.category_top, self.user_alice, self.role_owner
         )
 
@@ -506,44 +519,38 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
         self.assertEqual(repr(self.assignment_owner), expected)
 
     def test_validate_user(self):
-        """Test user role uniqueness validation: can't add more than one
-        role for user in project at once"""
+        """Test adding more than one role for user in project (should fail)"""
         with self.assertRaises(ValidationError):
-            self._make_assignment(
+            self.make_assignment(
                 self.category_top, self.user_alice, self.role_contributor
             )
 
     def test_validate_owner(self):
-        """Test owner uniqueness validation: can't add owner for project if
-        one already exists"""
+        """Test adding owner if one exists (should fail)"""
         with self.assertRaises(ValidationError):
-            self._make_assignment(
+            self.make_assignment(
                 self.category_top, self.user_bob, self.role_owner
             )
 
     @override_settings(PROJECTROLES_DELEGATE_LIMIT=1)
     def test_validate_one_delegate(self):
-        """Test delegate validation: can't add delegate for project if limit (1)
-        of delegates is reached"""
-        self._make_assignment(
+        """Test adding delegate if limit (1) is reached (should fail)"""
+        self.make_assignment(
             self.project_sub, self.user_bob, self.role_delegate
         )
-
         with self.assertRaises(ValidationError):
-            self._make_assignment(
+            self.make_assignment(
                 self.project_sub, self.user_carol, self.role_delegate
             )
 
     @override_settings(PROJECTROLES_DELEGATE_LIMIT=0)
     def test_validate_several_delegates(self):
-        """Test delegate validation: can add delegate for project if no limit
-        of delegates is set"""
-        self._make_assignment(
+        """Test adding validation with no limit set"""
+        self.make_assignment(
             self.project_sub, self.user_bob, self.role_delegate
         )
-
         try:
-            self._make_assignment(
+            self.make_assignment(
                 self.project_sub, self.user_carol, self.role_delegate
             )
         except ValidationError as e:
@@ -575,10 +582,8 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
 
     def test_get_project_owners(self):
         """Test project.get_owners() results"""
-
         # Set bob as project owner
-        self._make_assignment(self.project_sub, self.user_bob, self.role_owner)
-
+        self.make_assignment(self.project_sub, self.user_bob, self.role_owner)
         self.assertEqual(len(self.project_sub.get_owners()), 2)
         self.assertEqual(
             len(self.project_sub.get_owners(inherited_only=True)), 1
@@ -586,17 +591,14 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
 
     def test_is_project_owner(self):
         """Test project.is_owner() reuslts"""
-
-        # Set bob as project owner
-        self._make_assignment(self.project_sub, self.user_bob, self.role_owner)
-
+        self.make_assignment(self.project_sub, self.user_bob, self.role_owner)
         self.assertTrue(self.project_sub.is_owner(self.user_bob))
         self.assertTrue(self.project_sub.is_owner(self.user_alice))
         self.assertFalse(self.project_sub.is_owner(self.user_carol))
 
     def test_get_project_delegates(self):
         """Test get_project_delegates() results"""
-        assignment_d0 = self._make_assignment(
+        assignment_d0 = self.make_assignment(
             self.project_top, self.user_carol, self.role_delegate
         )
 
@@ -609,9 +611,8 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
                 'sodar_uuid': assignment_d0.sodar_uuid,
             }
         ]
-
         if getattr(settings, 'PROJECTROLES_DELEGATE_LIMIT', 1) != 1:
-            assignment_d1 = self._make_assignment(
+            assignment_d1 = self.make_assignment(
                 self.project_top, self.user_dan, self.role_delegate
             )
             expected.append(
@@ -625,16 +626,15 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
             )
 
         delegates = self.project_top.get_delegates()
-
         for i in range(0, delegates.count()):
             self.assertEqual(model_to_dict(delegates[i]), expected[i])
 
     def test_get_project_members(self):
         """Test project.get_members() results"""
-        assignment_c0 = self._make_assignment(
+        assignment_c0 = self.make_assignment(
             self.project_top, self.user_erin, self.role_contributor
         )
-        assignment_c1 = self._make_assignment(
+        assignment_c1 = self.make_assignment(
             self.project_top, self.user_frank, self.role_contributor
         )
 
@@ -656,15 +656,12 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
         ]
 
         members = self.project_top.get_members()
-
         for i in range(0, members.count()):
             self.assertEqual(model_to_dict(members[i]), expected[i])
 
     def test_get_all_project_roles(self):
         """Test project.get_all_roles() results"""
-
-        # Set bob as project owner
-        self._make_assignment(self.project_sub, self.user_bob, self.role_owner)
+        self.make_assignment(self.project_sub, self.user_bob, self.role_owner)
         self.assertEqual(len(self.project_sub.get_all_roles()), 2)
 
     def test_has_role(self):
@@ -673,9 +670,8 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
         self.assertEqual(self.project_sub.has_role(self.user_alice), True)
 
     def test_has_role_norole(self):
-        """Test the has_role() function for a non-existing role without
-        recursion"""
-        self._make_assignment(
+        """Test the has_role() function for a non-existing role without recursion"""
+        self.make_assignment(
             self.project_sub, self.user_bob, self.role_contributor
         )
         self.assertEqual(self.category_top.has_role(self.user_bob), False)
@@ -683,7 +679,7 @@ class TestRoleAssignment(ProjectMixin, RoleAssignmentMixin, TestCase):
     def test_has_role_norole_children(self):
         """Test the has_role() function for a non-existing role with
         recursion using include_children"""
-        self._make_assignment(
+        self.make_assignment(
             self.project_sub, self.user_bob, self.role_contributor
         )
         self.assertEqual(
@@ -699,23 +695,20 @@ class TestProjectInvite(
 
     def setUp(self):
         # Init project
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProject', type=PROJECT_TYPE_PROJECT, parent=None
         )
-
         # Init roles
         self.role_owner = Role.objects.get(name=PROJECT_ROLE_OWNER)
         self.role_delegate = Role.objects.get(name=PROJECT_ROLE_DELEGATE)
         self.role_contributor = Role.objects.get(name=PROJECT_ROLE_CONTRIBUTOR)
-
         # Init user & role
         self.user = self.make_user('owner')
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
-
         # Init invite
-        self.invite = self._make_invite(
+        self.invite = self.make_invite(
             email='test@example.com',
             project=self.project,
             role=self.role_contributor,
@@ -746,6 +739,13 @@ class TestProjectInvite(
         )
         self.assertEqual(str(self.invite), expected)
 
+    def test_get_log_title(self):
+        """Test get_log_title() results"""
+        expected = '"{}" ({})'.format(
+            self.project.title, self.project.sodar_uuid
+        )
+        self.assertEqual(str(self.project.get_log_title()), expected)
+
     def test__repr__(self):
         """Test ProjectInvite __repr__()"""
         expected = (
@@ -759,16 +759,13 @@ class TestProjectManager(ProjectMixin, RoleAssignmentMixin, TestCase):
     """Tests for ProjectManager"""
 
     def setUp(self):
-        # Init projects/categories
-        # Top level category
-        self.category_top = self._make_project(
+        self.category_top = self.make_project(
             title='TestCategoryTop',
             type=PROJECT_TYPE_CATEGORY,
             parent=None,
             description='XXX',
         )
-        # Subproject under category_top
-        self.project_sub = self._make_project(
+        self.project_sub = self.make_project(
             title='TestProjectSub',
             type=PROJECT_TYPE_PROJECT,
             parent=self.category_top,
@@ -840,48 +837,43 @@ class TestProjectSetting(
     # NOTE: This assumes an example app is available
     def setUp(self):
         # Init project
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProject', type=PROJECT_TYPE_PROJECT, parent=None
         )
-
         # Init role
         self.role_owner = Role.objects.get(name=PROJECT_ROLE_OWNER)
-
         # Init user & role
         self.user = self.make_user('owner')
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
 
         # Init test setting
-        self.setting_str = self._make_setting(
+        self.setting_str = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='str_setting',
             setting_type='STRING',
             value='test',
             project=self.project,
         )
-
         # Init integer setting
-        self.setting_int = self._make_setting(
+        self.setting_int = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='int_setting',
             setting_type='INTEGER',
             value=170,
             project=self.project,
         )
-
         # Init boolean setting
-        self.setting_bool = self._make_setting(
+        self.setting_bool = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='bool_setting',
             setting_type='BOOLEAN',
             value=True,
             project=self.project,
         )
-
         # Init JSON setting
-        self.setting_json = self._make_setting(
+        self.setting_json = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='json_setting',
             setting_type='JSON',
@@ -985,36 +977,32 @@ class TestUserSetting(
     def setUp(self):
         # Init user & role
         self.user = self.make_user('owner')
-
         # Init test setting
-        self.setting_str = self._make_setting(
+        self.setting_str = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='str_setting',
             setting_type='STRING',
             value='test',
             user=self.user,
         )
-
         # Init integer setting
-        self.setting_int = self._make_setting(
+        self.setting_int = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='int_setting',
             setting_type='INTEGER',
             value=170,
             user=self.user,
         )
-
         # Init boolean setting
-        self.setting_bool = self._make_setting(
+        self.setting_bool = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='bool_setting',
             setting_type='BOOLEAN',
             value=True,
             user=self.user,
         )
-
-        # Init json setting
-        self.setting_json = self._make_setting(
+        # Init JSON setting
+        self.setting_json = self.make_setting(
             app_name=EXAMPLE_APP_NAME,
             name='json_setting',
             setting_type='JSON',
@@ -1117,21 +1105,18 @@ class TestProjectUserTag(
 
     def setUp(self):
         # Init project
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProject', type=PROJECT_TYPE_PROJECT, parent=None
         )
-
         # Init role
         self.role_owner = Role.objects.get(name=PROJECT_ROLE_OWNER)
-
         # Init user & role
         self.user = self.make_user('owner')
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
-
         # Init tag
-        self.tag = self._make_tag(self.project, self.user, PROJECT_TAG_STARRED)
+        self.tag = self.make_tag(self.project, self.user, PROJECT_TAG_STARRED)
 
     def test_initialization(self):
         """Test ProjectUserTag initialization"""
@@ -1162,21 +1147,18 @@ class TestRemoteSite(
 
     def setUp(self):
         # Init project
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProject', type=PROJECT_TYPE_PROJECT, parent=None
         )
-
         # Init role
         self.role_owner = Role.objects.get(name=PROJECT_ROLE_OWNER)
-
         # Init user & role
         self.user = self.make_user('owner')
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
-
         # Init remote site
-        self.site = self._make_site(
+        self.site = self.make_site(
             name=REMOTE_SITE_NAME,
             url=REMOTE_SITE_URL,
             mode=SODAR_CONSTANTS['SITE_MODE_TARGET'],
@@ -1217,9 +1199,8 @@ class TestRemoteSite(
 
     def test_validate_mode(self):
         """Test _validate_mode() with an invalid mode (should fail)"""
-
         with self.assertRaises(ValidationError):
-            self._make_site(
+            self.make_site(
                 name='New site',
                 url='http://example.com',
                 mode='uGaj9eicQueib1th',
@@ -1237,34 +1218,30 @@ class TestRemoteProject(
 
     def setUp(self):
         # Init project
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProject', type=PROJECT_TYPE_PROJECT, parent=None
         )
-
         # Init role
         self.role_owner = Role.objects.get(name=PROJECT_ROLE_OWNER)
         self.role_delegate = Role.objects.get_or_create(
             name=PROJECT_ROLE_DELEGATE
         )[0]
-
         # Init user & role
         self.user = self.make_user('owner')
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
         self.user_alice = self.make_user('alice')
         self.user_bob = self.make_user('bob')
-
         # Init remote site
-        self.site = self._make_site(
+        self.site = self.make_site(
             name=REMOTE_SITE_NAME,
             url=REMOTE_SITE_URL,
             mode=SITE_MODE_TARGET,
             description='',
             secret=REMOTE_SITE_SECRET,
         )
-
-        self.remote_project = self._make_remote_project(
+        self.remote_project = self.make_remote_project(
             project_uuid=self.project.sodar_uuid,
             site=self.site,
             level=SODAR_CONSTANTS['REMOTE_LEVEL_VIEW_AVAIL'],
@@ -1333,15 +1310,12 @@ class TestRemoteProject(
     @override_settings(PROJECTROLES_SITE_MODE=SITE_MODE_TARGET)
     @override_settings(PROJECTROLES_DELEGATE_LIMIT=1)
     def test_validate_remote_delegates(self):
-        """Test delegate validation: can add delegate for remote project even if
-        there is a limit"""
+        """Test delegate validation: can add for remote project with limit"""
         self.site.mode = SITE_MODE_SOURCE
         self.site.save()
-
-        self._make_assignment(self.project, self.user_bob, self.role_delegate)
-
+        self.make_assignment(self.project, self.user_bob, self.role_delegate)
         try:
-            self._make_assignment(
+            self.make_assignment(
                 self.project, self.user_alice, self.role_delegate
             )
         except ValidationError as e:
