@@ -75,30 +75,30 @@ class TestTemplateTagsBase(
         self.user = self.make_user('user_owner')
 
         # Init category
-        self.category = self._make_project(
+        self.category = self.make_project(
             title='TestCategoryTop', type=PROJECT_TYPE_CATEGORY, parent=None
         )
 
         # Init project under category
-        self.project = self._make_project(
+        self.project = self.make_project(
             title='TestProjectSub',
             type=PROJECT_TYPE_PROJECT,
             parent=self.category,
         )
 
         # Init role assignments
-        self.owner_as_cat = self._make_assignment(
+        self.owner_as_cat = self.make_assignment(
             self.category, self.user, self.role_owner
         )
-        self.owner_as = self._make_assignment(
+        self.owner_as = self.make_assignment(
             self.project, self.user, self.role_owner
         )
 
         # Init app_setting
-        app_settings.set_app_setting(
+        app_settings.set(
             'filesfolders', 'allow_public_links', True, project=self.project
         )
-        app_settings.set_app_setting(
+        app_settings.set(
             'projectroles', 'ip_restrict', True, project=self.project
         )
         self.setting_filesfolders = AppSetting.objects.get(
@@ -508,7 +508,7 @@ class TestProjectrolesTemplateTags(TestTemplateTagsBase):
             tags.is_app_visible(app_plugin, self.project, self.user), False
         )
         self.assertEqual(
-            tags.is_app_visible(app_plugin, self.project, superuser), True
+            tags.is_app_visible(app_plugin, self.project, superuser), False
         )
 
     def test_is_inherited_owner(self):
