@@ -1,6 +1,6 @@
 from django.conf.urls import url
 
-from . import views
+from userprofile import views
 
 app_name = 'userprofile'
 
